from pltpublish.pltpublish import (
    extract_legend_as_figure,
    save_fig,
    setup,
    setup_colorblind,
    setup_latex_fonts,
    set_size_pixels,
    layout_for_subplots,
)

__version__ = "1.0.2"
